Resolver
========

.. currentmodule:: class_resolver

.. autoclass:: Resolver
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Resolver.options

   .. rubric:: Methods Summary

   .. autosummary::

      ~Resolver.docdata
      ~Resolver.extract_name
      ~Resolver.extract_synonyms
      ~Resolver.from_entrypoint
      ~Resolver.from_subclasses
      ~Resolver.get_option
      ~Resolver.lookup
      ~Resolver.make
      ~Resolver.make_from_kwargs
      ~Resolver.make_many
      ~Resolver.make_safe
      ~Resolver.normalize
      ~Resolver.normalize_cls
      ~Resolver.normalize_inst
      ~Resolver.optuna_lookup
      ~Resolver.ray_tune_search_space
      ~Resolver.register
      ~Resolver.register_entrypoint
      ~Resolver.signature
      ~Resolver.supports_argument

   .. rubric:: Attributes Documentation

   .. autoattribute:: options

   .. rubric:: Methods Documentation

   .. automethod:: docdata
   .. automethod:: extract_name
   .. automethod:: extract_synonyms
   .. automethod:: from_entrypoint
   .. automethod:: from_subclasses
   .. automethod:: get_option
   .. automethod:: lookup
   .. automethod:: make
   .. automethod:: make_from_kwargs
   .. automethod:: make_many
   .. automethod:: make_safe
   .. automethod:: normalize
   .. automethod:: normalize_cls
   .. automethod:: normalize_inst
   .. automethod:: optuna_lookup
   .. automethod:: ray_tune_search_space
   .. automethod:: register
   .. automethod:: register_entrypoint
   .. automethod:: signature
   .. automethod:: supports_argument
